# alpsplot

[![contact](https://img.shields.io/badge/contact-rbp5354@psu.edu-yellow)](mailto:rbp5354@psu.edu)

![python>=3.9](https://img.shields.io/badge/python->=3.9.2-informational.svg)
[![License](https://img.shields.io/github/license/ain-soph/alpsplot)](https://opensource.org/licenses/GPL-3.0)

[![codecov](https://codecov.io/gh/ain-soph/alpsplot/branch/main/graph/badge.svg?token=BBYZUPVK3I)](https://codecov.io/gh/ain-soph/alpsplot)

[![release](https://img.shields.io/github/v/release/ain-soph/alpsplot)](https://github.com/ain-soph/alpsplot/releases)
[![pypi](https://img.shields.io/pypi/v/alpsplot)](https://pypi.org/project/alpsplot/)

Python plotting library of alps-lab style using matplotlib.